| /netbsd-src/external/gpl3/gdb.old/dist/gdb/testsuite/gdb.linespec/ |
| H A D | lspec.h | 5 int overload (); 6 int overload (int); 7 int overload (double);
|
| H A D | lspec.cc | 5 int NameSpace::overload() in overload() function in NameSpace
|
| /netbsd-src/external/gpl3/gdb/dist/gdb/testsuite/gdb.linespec/ |
| H A D | lspec.h | 5 int overload (); 6 int overload (int); 7 int overload (double);
|
| H A D | lspec.cc | 5 int NameSpace::overload() in overload() function in NameSpace
|
| /netbsd-src/external/gpl3/gcc/usr.bin/ |
| H A D | rs6000-inc.mk | 15 ${DIST}/gcc/config/rs6000/rs6000-overload.def 19 ${DIST}/gcc/config/rs6000/rs6000-overload.def \
|
| /netbsd-src/external/apache2/llvm/dist/llvm/docs/ |
| H A D | CompileCudaWithLLVM.rst | 309 However, nvcc allows you to "overload" H and D functions with different 344 overload resolution. See `IdentifyCUDAPreference 373 foo(); // calls H overload 374 bar(); // calls H overload 378 foo(); // calls D overload 379 bar(); // calls HD overload 383 foo(); // calls H overload when compiling for host, otherwise D overload 384 bar(); // always calls HD overload 449 // have ifdef'ed away the __device__ overload of S::foo(). The __device__ 450 // overload must be present *even during host compilation*. [all …]
|
| /netbsd-src/external/ibm-public/postfix/dist/ |
| H A D | RELEASE_NOTES-2.6 | 109 after replying with "521". This makes overload handling more 121 Under conditions of overload, smtpd_timeout is reduced from 300s 124 the impact of overload for most legitimate mail. 141 after replying with "521". This makes overload handling more 145 Under conditions of overload, smtpd_timeout is reduced from 300s 148 the negative impact of server overload for most legitimate mail.
|
| /netbsd-src/external/gpl3/gdb.old/dist/gdb/testsuite/gdb.linespec/base/one/ |
| H A D | thefile.cc | 22 int NameSpace::overload(int x) in overload() function in NameSpace
|
| /netbsd-src/external/gpl3/gdb/dist/gdb/testsuite/gdb.linespec/base/one/ |
| H A D | thefile.cc | 22 int NameSpace::overload(int x) in overload() function in NameSpace
|
| /netbsd-src/external/gpl3/gdb/dist/gdb/testsuite/gdb.linespec/base/two/ |
| H A D | thefile.cc | 23 int NameSpace::overload(double x) in overload() function in NameSpace
|
| /netbsd-src/external/gpl3/gdb.old/dist/gdb/testsuite/gdb.linespec/base/two/ |
| H A D | thefile.cc | 23 int NameSpace::overload(double x) in overload() function in NameSpace
|
| /netbsd-src/external/gpl3/gcc/dist/gcc/cp/ |
| H A D | tree.cc | 2427 ovl_iterator::reveal_node (tree overload, tree node) in reveal_node() argument 2440 overload = remove_node (overload, node); in reveal_node() 2441 overload = ovl_insert (OVL_FUNCTION (node), overload); in reveal_node() 2446 return overload; in reveal_node() 2455 ovl_iterator::remove_node (tree overload, tree node) in remove_node() argument 2457 tree *slot = &overload; in remove_node() 2476 return overload; in remove_node() 3692 tree overload, ...) in build_min_non_dep_op_overload() argument 3703 if (TREE_CODE (TREE_TYPE (overload)) == METHOD_TYPE) in build_min_non_dep_op_overload() 3713 va_start (p, overload); in build_min_non_dep_op_overload() [all …]
|
| H A D | typeck.cc | 3571 tree overload = NULL_TREE; in build_x_indirect_ref() local 3598 &overload, complain); in build_x_indirect_ref() 3604 if (overload != NULL_TREE) in build_x_indirect_ref() 3606 (INDIRECT_REF, rval, overload, orig_expr)); in build_x_indirect_ref() 4551 tree overload = NULL_TREE; in build_x_binary_op() local 4574 lookups, &overload, complain); in build_x_binary_op() 4577 *overload_p = overload; in build_x_binary_op() 4594 if (overload != NULL_TREE) in build_x_binary_op() 4596 (code, expr, overload, orig_arg1, orig_arg2)); in build_x_binary_op() 4613 tree overload = NULL_TREE; in build_x_array_ref() local [all …]
|
| /netbsd-src/sys/fs/nfs/common/ |
| H A D | bootp_subr.c | 143 int overload; member 179 int overload; member 1381 tctx->overload = *j; in bootpc_tag_helper() 1391 tctx->overload = 0; in bootpc_tag() 1403 if ((tctx->overload & OVERLOAD_FILE) != 0) in bootpc_tag() 1408 if ((tctx->overload & OVERLOAD_SNAME) != 0) in bootpc_tag() 1450 if ((gctx->tmptag.overload & OVERLOAD_SNAME) == 0) in bootpc_decode_reply() 1453 if ((gctx->tmptag.overload & OVERLOAD_FILE) == 0) in bootpc_decode_reply()
|
| /netbsd-src/external/gpl3/gcc/dist/libphobos/src/std/format/internal/ |
| H A D | write.d | 2306 enum overload = hasToString!(T, Char); 2310 static if (overload == HasToStringResult.customPutWriterFormatSpec) 2314 else static if (overload == HasToStringResult.customPutWriter) 2318 else static if (overload == HasToStringResult.constCharSinkFormatSpec) 2322 else static if (overload == HasToStringResult.constCharSinkFormatString) 2326 else static if (overload == HasToStringResult.constCharSink) 2330 else static if (overload == HasToStringResult.inCharSinkFormatSpec) 2334 else static if (overload == HasToStringResult.inCharSinkFormatString) 2338 else static if (overload == HasToStringResult.inCharSink) 2342 else static if (overload == HasToStringResult.hasSomeToString) [all …]
|
| /netbsd-src/external/apache2/llvm/dist/clang/lib/Headers/cuda_wrappers/ |
| H A D | algorithm | 39 // overload preceding it. So the simple thing to do would be to declare our 52 // overload resolution will prefer it over the __host__ __device__ version
|
| /netbsd-src/external/gpl3/gcc/dist/gcc/config/rs6000/ |
| H A D | t-rs6000 | 66 $(srcdir)/config/rs6000/rs6000-overload.def 69 $(srcdir)/config/rs6000/rs6000-overload.def rs6000-builtins.h \
|
| /netbsd-src/external/apache2/llvm/dist/clang/lib/Headers/openmp_wrappers/ |
| H A D | complex | 35 // compile against libstdc++, or any other standard library, we will overload
|
| /netbsd-src/external/gpl3/gcc.old/dist/gcc/cp/ |
| H A D | tree.c | 2315 ovl_iterator::reveal_node (tree overload, tree node) in reveal_node() argument 2328 overload = remove_node (overload, node); in reveal_node() 2329 overload = ovl_insert (OVL_FUNCTION (node), overload); in reveal_node() 2334 return overload; in reveal_node() 2343 ovl_iterator::remove_node (tree overload, tree node) in remove_node() argument 2345 tree *slot = &overload; in remove_node() 2364 return overload; in remove_node() 3484 tree overload, ...) in build_min_non_dep_op_overload() argument 3503 va_start (p, overload); in build_min_non_dep_op_overload() 3505 if (TREE_CODE (TREE_TYPE (overload)) == FUNCTION_TYPE) in build_min_non_dep_op_overload() [all …]
|
| H A D | NEWS | 114 to overload `operator new'; it is no longer allowed by the C++ 131 * G++ no longer allows you to overload the conditional operator (i.e., 153 * In overload resolution, type conversion operators are now properly 301 * The overload resolution code has been rewritten to conform to the latest 303 in operator overload resolution. Function template overloading chooses
|
| H A D | typeck.c | 3334 tree overload = NULL_TREE; in build_x_indirect_ref() local 3347 NULL_TREE, NULL_TREE, &overload, complain); in build_x_indirect_ref() 3353 if (overload != NULL_TREE) in build_x_indirect_ref() 3355 (INDIRECT_REF, rval, overload, orig_expr)); in build_x_indirect_ref() 4289 tree overload = NULL_TREE; in build_x_binary_op() local 4311 &overload, complain); in build_x_binary_op() 4314 *overload_p = overload; in build_x_binary_op() 4331 if (overload != NULL_TREE) in build_x_binary_op() 4333 (code, expr, overload, orig_arg1, orig_arg2)); in build_x_binary_op() 4350 tree overload = NULL_TREE; in build_x_array_ref() local [all …]
|
| /netbsd-src/external/bsd/openldap/dist/contrib/slapd-modules/ppm/ |
| H A D | INSTALL.md | 40 Here is an illustrative example showing how to overload some options:
|
| /netbsd-src/external/apache2/llvm/dist/libcxx/include/experimental/ |
| H A D | coroutine | 226 // NOTE: this overload isn't required by the standard but is needed so 227 // the deleted _Promise* overload doesn't make from_address(nullptr)
|
| /netbsd-src/external/gpl3/gcc.old/dist/gcc/config/arm/ |
| H A D | arm_cde_builtins.def | 44 overload resolution in `arm_resolve_overloaded_builtin`. */
|
| /netbsd-src/external/gpl3/gcc/dist/gcc/config/arm/ |
| H A D | arm_cde_builtins.def | 44 overload resolution in `arm_resolve_overloaded_builtin`. */
|